@@ -1,5 +1,6 @@
-context("onLoad")
+# onLoad:
 test_that("onLoad does not fail", {
+    skip_on_cran()
     library(tglkmeans)
     cores <- round(parallel::detectCores() / 2)
     if (cores == 1) {
@@ -9,8 +10,9 @@ test_that("onLoad does not fail", {
     }
 })
 
-context("number of threads")
+# number of threads:
 test_that("parallel is turned off when number of threads <= 1", {
+    skip_on_cran()
     withr::with_options(
         list(tglkmeans.parallel = TRUE),
         {
@@ -29,6 +31,7 @@ test_that("parallel is turned off when number of threads <= 1", {
 })
 
 test_that("parallel is turned on when number of threads is not 1", {
+    skip_on_cran()
     withr::with_options(
         list(tglkmeans.parallel = FALSE),
         {
